Re-exports
pub use self::diagnostics::DiagnosticsHandler;pub use self::diagnostics::Emitter;pub use self::flags::CompileFlag;pub use self::flags::CompileFlags;pub use self::flags::FlagAction;pub use miden_assembly_syntax;pub use miden_package_registry;pub use miden_project;
Modules
Structs
- ArgMatches
- Container for parse results.
- File
Name - Human
Duration - Input
File - This enum represents the types of raw inputs provided to the compiler
- Library
Path - Path to an item in a library, i.e. module, procedure, constant or type.
- Link
Library - A library requested by the user to be linked against during compilation
- Options
- This struct contains all of the configuration options for the compiler
- Output
Files - Output
Types - Package
Id - A type that represents the unique identifier for packages in a registry.
- Path
- A slice of a path (akin to
str). - PathBuf
- An owned, mutable path (akin to
String). - Remap
Path Prefix - Represents the
--remap-path-prefixflag, which rewrites source paths encoded in debug info with a different path, typically to avoid encoding machine-specific details in artifacts. - Report
- Core Diagnostic wrapper type.
- Session
- This struct provides access to all of the metadata and configuration needed during a single compilation session.
- Statistics
- This struct contains various statistics about a compilation session
Enums
- Color
Choice - ColorChoice represents the color preferences of an end user.
- Debug
Info - This enum describes what type of debugging information to emit in compiled programs
- File
Type - This represents the file types recognized by the compiler
- Input
Type - Invalid
Input Error - An error that occurs when detecting the file type of an input
- IrFilter
- ColorChoice represents the color preferences of an end user.
- Library
Path Component - Represents a single component of a Path
- OptLevel
- This enum describes the degree to which compiled programs will be optimized
- Output
File - Output
Mode - The type of output to produce for a given OutputType, when multiple options are available
- Output
Type - This enum represents the type of outputs the compiler can produce
- Output
Type Spec - This type describes an output type with optional path specification
- Verbosity
- This enum represents the type of messages produced by the compiler during execution
- Warnings
- This enum represents the behavior of the compiler with regard to warnings
Constants
- MIDENC_
BUILD_ REV - The git revision associated with the current compiler toolchain
- MIDENC_
BUILD_ VERSION - The version associated with the current compiler toolchain
Statics
Traits
- Emit
- EmitExt
- Source
Manager - Writer
- A trait that provides a subset of the std::io::Write functionality that is usable in no-std contexts.
Functions
- add_
target_ link_ libraries - Add libraries required by the target environment to the list of libraries to link against only if they are not already present.
- fixup_
targets