Crate midenc_session

Crate midenc_session 

Re-exports

pub use self::diagnostics::DiagnosticsHandler;
pub use self::diagnostics::Emitter;
pub use self::flags::CompileFlag;
pub use self::flags::CompileFlags;
pub use self::flags::FlagAction;
pub use miden_assembly_syntax;
pub use miden_package_registry;
pub use miden_project;

Modules

diagnostics
flags
path
registry

Structs

ArgMatches
Container for parse results.
FileName
HumanDuration
InputFile
This enum represents the types of raw inputs provided to the compiler
LibraryPath
Path to an item in a library, i.e. module, procedure, constant or type.
LinkLibrary
A library requested by the user to be linked against during compilation
Options
This struct contains all of the configuration options for the compiler
OutputFiles
OutputTypes
PackageId
A type that represents the unique identifier for packages in a registry.
Path
A slice of a path (akin to str).
PathBuf
An owned, mutable path (akin to String).
ProjectManifest
What a project’s manifest says about the targets it declares.
RemapPathPrefix
Represents the --remap-path-prefix flag, which rewrites source paths encoded in debug info with a different path, typically to avoid encoding machine-specific details in artifacts.
Report
Core Diagnostic wrapper type.
Session
This struct provides access to all of the metadata and configuration needed during a single compilation session.
Statistics
This struct contains various statistics about a compilation session

Enums

ColorChoice
ColorChoice represents the color preferences of an end user.
DebugInfo
This enum describes what type of debugging information to emit in compiled programs
FileType
This represents the file types recognized by the compiler
InputType
InvalidInputError
An error that occurs when detecting the file type of an input
IrFilter
ColorChoice represents the color preferences of an end user.
LibraryPathComponent
Represents a single component of a Path
OptLevel
This enum describes the degree to which compiled programs will be optimized
OutputFile
OutputMode
The type of output to produce for a given OutputType, when multiple options are available
OutputType
This enum represents the type of outputs the compiler can produce
OutputTypeSpec
This type describes an output type with optional path specification
Verbosity
This enum represents the type of messages produced by the compiler during execution
Warnings
This enum represents the behavior of the compiler with regard to warnings

Constants

MIDENC_BUILD_REV
The git revision associated with the current compiler toolchain
MIDENC_BUILD_VERSION
The version associated with the current compiler toolchain

Traits

Emit
EmitExt
SourceManager
Writer
A trait that provides a subset of the std::io::Write functionality that is usable in no-std contexts.

Functions

add_target_link_libraries
Add libraries required by the target environment to the list of libraries to link against only if they are not already present.